@@ -8,30 +8,12 @@ from time import sleep as time_sleep
 from typing import Callable, Dict, List, Optional
 
 import vlc
-from notifypy import Notify
-from tqdm import tqdm
 
-from exclock.util import get_real_sound_filename
+from exclock.util import get_real_sound_filename, get_time_delta_from_str, notify_all
 
 DEFAULT_TITLE = "ExClock"
 
 
-def get_time_from_str(s: str) -> int:
-    if s.isdigit():
-        return int(s)
-    else:
-        sec = 0
-        m_ind = s.find("m")
-        if m_ind != -1:
-            sec += 60 * int(s[:m_ind])
-
-        s_ind = s.find("s")
-        if s_ind == -1:
-            return sec
-        sec += int(s[m_ind + 1:s_ind])
-        return sec
-
-
 def inner_str(s: str, d: dict) -> str:
     start_secs: List[int] = []
     end_secs: List[int] = []
@@ -118,18 +100,8 @@ class ClockTimer:
         secs = list(sounds.keys())
         for i, (sec, sound) in enumerate(sounds.items()):
             spend_time = secs[i] - (0 if i == 0 else secs[i - 1])
-            tqdm_f = (lambda i: i) if sec == 0 else lambda i: tqdm(
-                i, bar_format="{l_bar}{bar}| {n_fmt}/{total_fmt} ")
-            for _ in tqdm_f(range(spend_time)):
-                time_sleep(1)
-
-            notification = Notify()
-            notification.application_name = "Exclock"
-            notification.title = self.title
-            notification.message = inner_str(sound.message, {"count": count})
-            notification.send()
-
-            print(notification.message)
+            message = inner_str(sound.message, {"count": count})
+            notify_all(title=self.title, message=message, spend_time=spend_time)
 
             ps.append(sound.run())
             sound.confirm_f()
@@ -152,7 +124,7 @@ class ClockTimer:
     def from_dict(cls, json: dict) -> ClockTimer:
         sounds = {}
         for sec, sound in json["sounds"].items():
-            sec = get_time_from_str(sec)
+            sec = get_time_delta_from_str(sec)
             sounds[sec] = Sound.from_dict(sound)
 
         return ClockTimer(sounds=sounds, loop=json["loop"], title=json["title"])
