@@ -21,9 +21,16 @@ from exclock.util import (
 
 from .test_const import TEST_CLOCK_DIR_IN_SYS, TEST_SOUND_DIR_IN_SYS
 
+
+def test_ASSET_FILES_IN_PROG():
+    """ IN_PROGのディレクトリが存在することのテスト """
+    assert CLOCK_DIR_IN_PROG.exists()
+    assert SOUND_DIR_IN_PROG.exists()
+
+
 GET_CLOCK_BASENAMES_PARAMS = [
     ("pomodoro", True),
-    ("3", True),
+    ("3m", True),
     ("not_exists", False),
 ]
 
